diff --git a/configuration.nix b/configuration.nix
index 5aa5655..ee8040c 100644
--- a/configuration.nix
+++ b/configuration.nix
@@ -34,16 +34,15 @@
   boot.cleanTmpDir = true;
 
   # Set hostname
-  networking.hostName = "zion";
+  networking.hostName = "aegis";
 
-  # Create coolneng user
-  users.users.coolneng = {
+  # Create coace user
+  users.users.coace = {
     isNormalUser = true;
-    home = "/home/coolneng";
-    extraGroups = [ "wheel" "docker" ];
-    openssh.authorizedKeys.keys = [
-      "ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAIFRqINHR7/zc+c3/PuR+NeSsBHXXzBiEtFWSK6QaxQTW coolneng@panacea"
-    ];
+    extraGroups = [ "wheel" ];
+    openssh.authorizedKeys.keys = [''
+      ssh-ed25519 AAAAC3NzaC1lZDI1NTE5AAAAINNmNckWBxa2fQkUjWLHgQd32C272yB+f9kTcnooszd5 coolneng@panacea
+    ''];
     shell = "${pkgs.fish}/bin/fish";
   };